@@ -190,12 +190,13 @@ func (v *TimedUserValidator) Remove(email string) bool {
 	v.Lock()
 	defer v.Unlock()
 
+	email = strings.ToLower(email)
 	idx := -1
-	for i := range v.users {
-		if strings.EqualFold(v.users[i].user.Email, email) {
+	for i, u := range v.users {
+		if strings.EqualFold(u.user.Email, email) {
 			idx = i
 			var cmdkeyfl [16]byte
-			copy(cmdkeyfl[:], v.users[i].user.Account.(*MemoryAccount).ID.CmdKey())
+			copy(cmdkeyfl[:], u.user.Account.(*MemoryAccount).ID.CmdKey())
 			v.aeadDecoderHolder.RemoveUser(cmdkeyfl)
 			break
 		}
