@@ -4,8 +4,6 @@ package kcp
 
 import (
 	"crypto/cipher"
-	"fmt"
-
 	"v2ray.com/core/common"
 	"v2ray.com/core/transport/internet"
 )
@@ -63,7 +61,6 @@ func (c *Config) GetReadBufferSize() uint32 {
 // GetSecurity returns the security settings.
 func (c *Config) GetSecurity() (cipher.AEAD, error) {
 	if c.Seed != nil {
-		fmt.Println("=========NewAEADAESGCMBasedOnSeed Used============")
 		return NewAEADAESGCMBasedOnSeed(c.Seed.Seed), nil
 	}
 	return NewSimpleAuthenticator(), nil
