@@ -10,6 +10,7 @@ import (
 	"v2ray.com/core/common/session"
 	"v2ray.com/core/transport/internet"
 	"v2ray.com/core/transport/internet/tls"
+	"v2ray.com/core/transport/internet/xtls"
 )
 
 // Dial dials a new TCP connection to the given destination.
@@ -21,12 +22,18 @@ func Dial(ctx context.Context, dest net.Destination, streamSettings *internet.Me
 	}
 
 	if config := tls.ConfigFromStreamSettings(streamSettings); config != nil {
-		tlsConfig := config.GetTLSConfig(tls.WithDestination(dest), tls.WithNextProto("h2"))
-		if config.IsExperiment8357() {
-			conn = tls.UClient(conn, tlsConfig)
-		} else {
-			conn = tls.Client(conn, tlsConfig)
-		}
+		tlsConfig := config.GetTLSConfig(tls.WithDestination(dest))
+		/*
+			if config.IsExperiment8357() {
+				conn = tls.UClient(conn, tlsConfig)
+			} else {
+				conn = tls.Client(conn, tlsConfig)
+			}
+		*/
+		conn = tls.Client(conn, tlsConfig)
+	} else if config := xtls.ConfigFromStreamSettings(streamSettings); config != nil {
+		xtlsConfig := config.GetXTLSConfig(xtls.WithDestination(dest))
+		conn = xtls.Client(conn, xtlsConfig)
 	}
 
 	tcpSettings := streamSettings.ProtocolSettings.(*Config)
